@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package IPC::Open3::Callback::Command;
-$IPC::Open3::Callback::Command::VERSION = '1.16';
+$IPC::Open3::Callback::Command::VERSION = '1.17';
 # ABSTRACT: A utility class that provides subroutines for building shell command strings.
 
 use Exporter qw(import);
@@ -46,10 +46,10 @@ sub command {
 sub cp_command {
     my ( $source_path, $source_command_options, $destination_path, $destination_command_options,
         %cp_options );
-    $source_path            = shift;
+    $source_path            = _escape_path(shift);
     $source_command_options = shift
         if ( ref( $_[0] ) eq 'IPC::Open3::Callback::Command::CommandOptions' );
-    $destination_path            = shift;
+    $destination_path            = _escape_path(shift);
     $destination_command_options = shift
         if ( ref( $_[0] ) eq 'IPC::Open3::Callback::Command::CommandOptions' );
     %cp_options = @_;
@@ -156,6 +156,12 @@ sub _quote_command {
     return "\"$command\"";
 }
 
+sub _escape_path {
+    my ($path) = @_;
+    $path =~ s/(['"`\s])/\\$1/g;
+    return $path;
+}
+
 sub rm_command {
     wrap(
         {},
@@ -303,7 +309,7 @@ sub wrap {
 }
 
 package IPC::Open3::Callback::Command::CommandOptions;
-$IPC::Open3::Callback::Command::CommandOptions::VERSION = '1.16';
+$IPC::Open3::Callback::Command::CommandOptions::VERSION = '1.17';
 use parent qw(Class::Accessor);
 __PACKAGE__->follow_best_practice;
 __PACKAGE__->mk_ro_accessors(qw(hostname pretty ssh sudo_username username));
@@ -357,7 +363,7 @@ IPC::Open3::Callback::Command - A utility class that provides subroutines for bu
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
